@@ -1,6 +1,6 @@
 package Dist::Zilla::App::CommandHelper::ChainSmoking;
 
-our $VERSION = '0.98_02'; # VERSION
+our $VERSION = '0.90'; # VERSION
 # ABSTRACT: Helper class for chainsmoke command
 
 use sanity;
@@ -31,7 +31,6 @@ has branch => ( isa => 'Str', is => 'ro', lazy => 1, default => sub {
 ### HACK: Needed for DirtyFiles, though this is really only used for Plugins ###
 sub mvp_multivalue_args { }
 
-with 'Dist::Zilla::Role::Git::Repo';
 with 'Dist::Zilla::Role::Git::DirtyFiles';
 sub _build_allow_dirty { [ ] }  # overload
 
@@ -165,8 +164,8 @@ sub prebuild {
 }
 
 42;
+ 
 
-__END__
 
 =pod
 
@@ -186,28 +185,17 @@ site near you, or see L<https://metacpan.org/module/Dist::Zilla::TravisCI/>.
 
 =head1 AUTHOR
 
-Brendan Byrd <bbyrd@cpan.org>
-
-=head1 CONTRIBUTORS
-
-=over 4
-
-=item *
-
-Graham Knop <haarg@haarg.org>
-
-=item *
-
-Torsten Raudssus <torsten@raudss.us>
-
-=back
+Brendan Byrd <BBYRD@CPAN.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2013 by Brendan Byrd.
+This software is Copyright (c) 2012 by Brendan Byrd.
 
 This is free software, licensed under:
 
   The Artistic License 2.0 (GPL Compatible)
 
 =cut
+
+
+__END__
