@@ -1,6 +1,6 @@
 package Dist::Zilla::Role::TravisYML;
 
-our $VERSION = '0.98_02'; # VERSION
+our $VERSION = '0.90'; # VERSION
 # ABSTRACT: Role for .travis.yml creation
 
 use sanity;
@@ -10,8 +10,8 @@ use MooseX::Has::Sugar;
 use MooseX::Types::Moose qw{ ArrayRef Str Bool is_Bool };
 
 use List::AllUtils qw{ first sum };
+use Acme::Indent qw(ai);  # no idea why this is Acme::
 use File::Slurp;
-use YAML qw{ DumpFile };
 
 use Module::CoreList;
 use version 0.77;
@@ -25,44 +25,48 @@ sub log       { shift->logger->log(@_)       }
 sub log_debug { shift->logger->log_debug(@_) }
 sub log_fatal { shift->logger->log_fatal(@_) }
 
-# needs our to pass to mvp_multivalue_args
-our @phases = qw(
-   before_install
-   install
-   before_script
-   script
-   after_success
-   after_failure
-   after_script
-);
-my @yml_order = (qw(
-   language
-   perl
-   branches
-), @phases, qw(
-   notifications
-));
-
-
 ### HACK: Need these rw for ChainSmoking ###
-has $_ => ( rw, isa => ArrayRef[Str], default => sub { [] } ) for (
-   map { $_, $_.'_dzil', $_.'_build' }
-   map { $_, 'pre_'.$_, 'post_'.$_ }
-   @phases
-);
+has build_branch  => ( rw, isa => Str,           default => '/^build\/.*/' );
+has notify_email  => ( rw, isa => ArrayRef[Str], default => sub { [ 1 ] }  );
+has notify_irc    => ( rw, isa => ArrayRef[Str], default => sub { [ 0 ] }  );
+has mvdt          => ( rw, isa => Bool,          default => 0              );
 
-has build_branch    => ( rw, isa => Str,           default => '/^build\/.*/' );
-has notify_email    => ( rw, isa => ArrayRef[Str], default => sub { [ 1 ] }  );
-has notify_irc      => ( rw, isa => ArrayRef[Str], default => sub { [ 0 ] }  );
-has mvdt            => ( rw, isa => Bool,          default => 0              );
-has test_authordeps => ( rw, isa => Bool,          default => 0              );
-has test_deps       => ( rw, isa => Bool,          default => 1              );
+has _header => ( ro, isa => Str, lazy, default => sub {
+   ai('
+      language: perl
+      perl:
+         - "5.16"
+         - "5.14"
+         - "5.12"
+         - "5.10"
+   ');
+});
+has _footer => ( ro, isa => Str, lazy, default => sub {
+   my $self = shift;
+   
+   my $email = $self->notify_email->[0];
+   my $irc   = $self->notify_irc->[0];
+   my $zilla = $self->zilla;
+   my $rmeta = $self->zilla->distmeta->{resources};
+   
+   no warnings 'numeric';  # *grumble*
+   
+   $irc == 1 and $irc = $self->notify_irc->[0] = $rmeta->{ first { /irc$/i } keys %$rmeta } || 0;
+   s#^irc:|/+##gi for @{$self->notify_irc};
+   
+   my $footer = '';
+   # Travis-CI default is to set email, but not use IRC
+   unless ($email == 1 && !$irc) {
+      $footer .=               "notifications:\n";
+      $footer .= $email == 0 ? "   email: false\n" :
+                 $email == 1 ? "" :
+                               "   email:\n".join("\n", map { '      - "'.$_.'"'; } grep { $_ } @{$self->notify_email})."\n";
 
-has irc_template  => ( rw, isa => ArrayRef[Str], default => sub { [
-   "%{branch}#%{build_number} by %{author}: %{message} (%{build_url})",
-] } );
-
-has perl_version  => ( rw, isa => Str, default => '5.16 5.14 5.12 5.10' );
+      $footer .=               "   irc:\n"  .join("\n", map { '      - "'.$_.'"'; } grep { $_ } @{$self->notify_irc  })."\n" if $irc;
+   }
+   
+   return $footer;
+});
 
 has _releases => ( ro, isa => ArrayRef[Str], lazy, default => sub {
    my $self = shift;
@@ -72,15 +76,15 @@ has _releases => ( ro, isa => ArrayRef[Str], lazy, default => sub {
    if ($self->mvdt) {
       my $prereqs = $self->zilla->prereqs;
       $self->log("Searching for minimum dependency versions");
-
+      
       my $minperl = version->parse(
          $prereqs->requirements_for('runtime', 'requires')->requirements_for_module('perl') ||
          v5.8.8  # released in 2006... C'mon, people!  Don't make me lower this!
       );
-      foreach my $phase (qw( runtime configure build test )) {
+      foreach my $phase (qw(runtime configure build test)) {
          $self->logger->set_prefix("{Phase '$phase'} ");
          my $req = $prereqs->requirements_for($phase, 'requires');
-
+         
          foreach my $module ( sort ($req->required_modules) ) {
             next if $module eq 'perl';  # obvious
 
@@ -88,160 +92,99 @@ has _releases => ( ro, isa => ArrayRef[Str], lazy, default => sub {
             my ($release, $minver) = $self->_mcpan_module_minrelease($module, $modver);
             next unless $release;
             my $mod_in_perlver = Module::CoreList->first_release($module, $minver);
-
+            
             if ($mod_in_perlver && $minperl >= $mod_in_perlver) {
                $self->log_debug(['Module %s v%s is already found in core Perl v%s (<= v%s)', $module, $minver, $mod_in_perlver, $minperl]);
                next;
             }
-
+            
             $self->log_debug(['Found minimum dep version for Module %s as %s', $module, $release]);
             push @releases, $release;
          }
       }
       $self->logger->clear_prefix;
    }
-
+   
    return \@releases;
 });
 
 sub build_travis_yml {
    my ($self, $is_build_branch) = @_;
-
-   my $zilla = $self->zilla;
-
-   my %travis_yml = ( 'language' => 'perl', 'perl' => [ split(/\s+/, $self->perl_version) ] );
-
-   my $email = $self->notify_email->[0];
-   my $irc   = $self->notify_irc->[0];
-   my $rmeta = $self->zilla->distmeta->{resources};
-
-   my %notifications;
-
-   # IRC
-   $irc eq "1" and $irc = $self->notify_irc->[0] = $rmeta->{ first { /irc$/i } keys %$rmeta } || "0";
-   s#^irc:|/+##gi for @{$self->notify_irc};
-
-   if ($irc) {
-      my %irc = (
-         on_success => 'change',
-         on_failure => 'always',
-         use_notice => 'true',
-      );
-      $irc{channels} = [grep { $_ } @{$self->notify_irc}];
-      $irc{template} = [grep { $_ } @{$self->irc_template}];
-      $notifications{irc} = \%irc;
-   }
-
-   # Email
-   $notifications{email} = ($email eq "0") ? \"false" : [ grep { $_ } @{$self->notify_email} ]
-      unless ($email eq "1");
-
-   $travis_yml{'notifications'} = \%notifications if (%notifications);
-
-   my $env_exports = 'export AUTOMATED_TESTING=1 HARNESS_OPTIONS=j10:c HARNESS_TIMER=1';
-
-   ### Prior to the custom mangling by the user, establish a default .travis.yml to work from
-
-   # needed for MDVT
-   my @releases = @{$self->_releases};
-   my @releases_install;
-   if (@releases) {
-      @releases_install = (
-         # Install the lowest possible required version for the dependencies
-         'export OLD_CPANM_OPT=$PERL_CPANM_OPT',
-         "export PERL_CPANM_OPT='--mirror http://cpan.metacpan.org/ --mirror http://search.cpan.org/CPAN' \$PERL_CPANM_OPT",
-         (map { 'cpanm --verbose '.$_ } @releases),
-         'export PERL_CPANM_OPT=$OLD_CPANM_OPT',
-      );
-   }
    
-   unless ($is_build_branch) {
-      # verbosity/testing and parallelized installs don't mix
-      my $notest_cmd = 'xargs -n 5 -P 10 cpanm --quiet --notest --skip-satisfied';
-      my $test_cmd   = 'cpanm --verbose --skip-satisfied';
+   my $header   = $self->_header;
+   my $footer   = $self->_footer;
+   my @releases = @{$self->_releases};
       
-      $travis_yml{before_install} = [
-         $env_exports,
-         # Fix for https://github.com/travis-ci/travis-cookbooks/issues/159
-         'git config --global user.name "TravisCI"',
-         'git config --global user.email $HOSTNAME":not-for-mail@travis-ci.org"',
-      ];
-      $travis_yml{install} = scalar(@releases) ? \@releases_install : [
-         "cpanm --quiet --notest --skip-satisfied Dist::Zilla",  # this should already exist anyway...
-         "dzil authordeps | grep -vP '[^\\w:]' | ".($self->test_authordeps ? $test_cmd : $notest_cmd),
-         "dzil listdeps   | grep -vP '[^\\w:]' | ".($self->test_deps       ? $test_cmd : $notest_cmd),
-      ];
-      $travis_yml{script} = [
-         "dzil smoke --release --author"
-      ];
+   unless ($is_build_branch) {
+      my $install = @releases ? join("\n", 
+         '   # Install the lowest possible required version for the dependencies',
+         '   - export OLD_CPANM_OPT=$PERL_CPANM_OPT',
+         "   - export PERL_CPANM_OPT='--mirror http://cpan.metacpan.org/ --mirror http://search.cpan.org/CPAN '\$PERL_CPANM_OPT",
+         (map { '   - cpanm --verbose '.$_ } @releases),
+         '   - export PERL_CPANM_OPT=$OLD_CPANM_OPT',
+      ) :
+         '   - dzil listdeps | cpanm --verbose'
+      ;
+
+      File::Slurp::write_file( '.travis.yml', join("\n",
+         $header,
+         ai("
+            install:
+               # Deal with all of the DZIL dependancies, quickly and quietly
+               - cpanm --quiet --notest --skip-satisfied Dist::Zilla
+               - dzil authordeps | cpanm --quiet --notest --skip-satisfied
+         "),
+         $install,
+         'script:',
+         '   - dzil smoke --release --author',
+         $footer,
+      ) );
    }
    elsif (my $bbranch = $self->build_branch) {
-      $travis_yml{before_install} = [
-          $env_exports,
-          # Prevent any test problems with this file
-         'rm .travis.yml',
-      ];
-      $travis_yml{install} = scalar(@releases) ? \@releases_install : [
-         'cpanm --installdeps --verbose '.($self->test_deps ? '' : '--notest').' --skip-satisfied .',
-      ];
+      my $install = @releases ? join ("\n",
+         'install:',
+         '   # Install the lowest possible required version for the dependencies',
+         '   - export OLD_CPANM_OPT=$PERL_CPANM_OPT',
+         "   - export PERL_CPANM_OPT='--mirror http://cpan.metacpan.org/ --mirror http://search.cpan.org/CPAN '\$PERL_CPANM_OPT",
+         (map { '   - cpanm --verbose '.$_ } @releases),
+         '   - export PERL_CPANM_OPT=$OLD_CPANM_OPT',
+      ) :
+         '# Travis-CI defaults should be enough'
+      ;
 
-      $travis_yml{'branches'} = { only => $bbranch };
+      File::Slurp::write_file(
+         Path::Class::File->new($self->zilla->built_in, '.travis.yml')->stringify,
+         join("\n",
+            $header,
+            'before_install:',
+            '   # Prevent any test problems with this file',
+            '   - rm .travis.yml',
+            $install,
+            '',
+            ai("
+               # whitelist
+               branches:
+                  only:
+                    - $bbranch
+            "),
+            $footer,
+         )
+      );
    }
-   else {
-      return;  # no point in staying here...
-   }
-
-   ### See if any custom code is requested
-   
-   my $ft_suffix = $is_build_branch ? '_build' : '_dzil';
-   foreach my $phase (@phases) {
-      # First, replace any new blocks, then deal with pre/post blocks
-      foreach my $ft ('', $ft_suffix) {  # YML file type; specific wins priority
-         my $method = $phase.$ft;
-         my $custom_cmds = $self->$method;
-         $travis_yml{$phase} = [ @$custom_cmds ] if ($custom_cmds && @$custom_cmds);
-      }
-      
-      foreach my $ft ('', $ft_suffix) {
-         foreach my $pos (qw(pre post)) {
-            my $method = $pos.'_'.$phase.$ft;
-            my $custom_cmds = $self->$method;
-            
-            if ($custom_cmds && @$custom_cmds) {
-               $pos eq 'pre' ?
-                  unshift(@{$travis_yml{$phase}}, @$custom_cmds) :
-                  push   (@{$travis_yml{$phase}}, @$custom_cmds)
-               ;
-            }
-         }
-      }
-   }
-   
-   ### Dump YML (in order)
-   local $YAML::Indent    = 3;
-   local $YAML::UseHeader = 0;
-
-   my $node = YAML::Bless(\%travis_yml);
-   $node->keys([grep { exists $travis_yml{$_} } @yml_order]);
-   $self->log( "Rebuilding .travis.yml".($is_build_branch ? ' (in build dir)' : '') );
-   
-   my $file = Path::Class::File->new($self->zilla->built_in, '.travis.yml');
-   DumpFile($file->stringify, \%travis_yml);
-   return $file;
 }
 
 sub _as_lucene_query {
    my ($self, $ver_str) = @_;
-
+   
    # simple versions short-circuits
    return () if $ver_str eq '0';
    return ('module.version_numified:['.version->parse($ver_str)->numify.' TO 999999]')
       unless ($ver_str =~ /[\<\=\>]/);
-
+   
    my ($min, $max, $is_min_inc, $is_max_inc, @num_conds, @str_conds);
    foreach my $ver_cmp (split(qr{\s*,\s*}, $ver_str)) {
       my ($cmp, $ver) = split(qr{(?<=[\<\=\>])\s*(?=\d)}, $ver_cmp, 2);
-
+      
       # Normalize string, but keep originals for alphas
       my $use_num = 1;
       my $orig_ver = $ver;
@@ -253,7 +196,7 @@ sub _as_lucene_query {
          $use_num = 0;
       }
       else { $ver = $num_ver; }
-
+      
       for ($cmp) {
          when ('==') { return 'module.version'.($use_num ? '_numified' : '').':'.$ver; }  # no need to look at anything else
          when ('!=') { $use_num ? push(@num_conds, '-'.$ver) : push(@str_conds, '-'.$ver); }
@@ -265,20 +208,20 @@ sub _as_lucene_query {
          default     { die 'Unable to parse complex module requirements with operator of '.$cmp.' !'; }
       }
    }
-
+   
    # Min/Max parsing
    if ($min || $max) {
       $min ||= 0;
       $max ||= 999999;
       my $rng = $min.' TO '.$max;
-
+      
       # Figure out the inclusive/exclusive status
       my $inc = $is_min_inc.$is_max_inc;  # (this is just easier to deal with as a combined form)
       unshift @num_conds, '-'.($inc eq '01' ? $min : $max)
          if ($inc =~ /0/ && $inc =~ /\d\d/);  # has mismatch of inc/exc (reverse order due to unshift)
       unshift @num_conds, '+'.($inc =~ /1/ ? '['.$rng.']' : '{'.$rng.'}');  # +[{ $min TO $max }]
    }
-
+   
    # Create the string
    my @lq;
    push @lq, 'module.version_numified:('.join(' ', @num_conds).')' if @num_conds;
@@ -288,10 +231,10 @@ sub _as_lucene_query {
 
 sub _mcpan_module_minrelease {
    my ($self, $module, $ver_str, $try_harder) = @_;
-
+  
    my @lq = $self->_as_lucene_query($ver_str);
    my $maturity_q = ($ver_str =~ /==/) ? undef : 'maturity:released';  # exact version may be a developer one
-
+   
    ### XXX: This should be replaced with a ->file() method when those
    ### two pull requests of mine are put into CPAN...
    my $q = join(' AND ', 'module.name:"'.$module.'"', $maturity_q, 'module.authorized:true', @lq);
@@ -317,7 +260,7 @@ sub _mcpan_module_minrelease {
       # (ie: we shouldn't have multiples of modules or versions, and sort should actually have a value)
       $is_bad = !$hit->{sort}[0] || ref $hit->{fields}{'module.name'} || ref $hit->{fields}{'module.version'};
    } while ($is_bad and @hits);
-
+   
    if ($is_bad) {
       if ($try_harder) {
          $self->log("??? MetaCPAN is highly confused about $module!");
@@ -326,9 +269,9 @@ sub _mcpan_module_minrelease {
       $self->log_debug("   MetaCPAN got confused; trying harder...");
       return $self->_mcpan_module_minrelease($module, $ver_str, 1)
    }
-
+   
    $hit = $hit->{fields};
-
+   
    # This will almost always be .tar.gz, but TRIAL versions might have different names, etc.
    my $fields = $self->mcpan->release(
       search => {
@@ -342,26 +285,26 @@ sub _mcpan_module_minrelease {
    my $t = $fields->{tests};
    my $ttl = sum @$t{qw(pass fail unknown na)};
    unless ($ttl) {
-      $self->log(['%s has no CPAN test results!  You should consider upgrading the minimum dep version for %s...', $hit->{release}, $module]);
+      $self->log(['%s has no CPAN test results!  You should consider upgrading the minimum dep version for %s...', $hit->{release}, $module]);   
    }
    else {
       my $per   = $t->{pass} / $ttl * 100;
       my $f_ttl = $ttl - $t->{pass};
-
+      
       if ($per < 70 || $t->{fail} > 20 || $f_ttl > 30) {
          $self->log(['CPAN Test Results for %s:', $hit->{release}]);
          $self->log(['   %7s: %4u (%3.1f)', $_, $t->{lc $_}, $t->{lc $_} / $ttl * 100]) for (qw(Pass Fail Unknown NA));
          $self->log(['You should consider upgrading the minimum dep version for %s...', $module]);
       }
    }
-
+   
    my $v = $hit->{'module.version'};
    return ($hit->{author}.'/'.$fields->{archive}, $v && version->parse($v));
 }
 
 42;
+ 
 
-__END__
 
 =pod
 
@@ -381,28 +324,17 @@ site near you, or see L<https://metacpan.org/module/Dist::Zilla::TravisCI/>.
 
 =head1 AUTHOR
 
-Brendan Byrd <bbyrd@cpan.org>
-
-=head1 CONTRIBUTORS
-
-=over 4
-
-=item *
-
-Graham Knop <haarg@haarg.org>
-
-=item *
-
-Torsten Raudssus <torsten@raudss.us>
-
-=back
+Brendan Byrd <BBYRD@CPAN.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2013 by Brendan Byrd.
+This software is Copyright (c) 2012 by Brendan Byrd.
 
 This is free software, licensed under:
 
   The Artistic License 2.0 (GPL Compatible)
 
 =cut
+
+
+__END__
\ No newline at end of file
